==> io-mokamint-application-messages-1.1.0-sources.jar: io/mokamint/application/messages/CheckPrologExtraResultMessages.java <==
/*
Copyright 2024 Fausto Spoto

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package io.mokamint.application.messages;

import io.mokamint.application.messages.api.CheckPrologExtraResultMessage;
import io.mokamint.application.messages.internal.CheckPrologExtraResultMessageImpl;
import io.mokamint.application.messages.internal.gson.CheckPrologExtraResultMessageDecoder;
import io.mokamint.application.messages.internal.gson.CheckPrologExtraResultMessageEncoder;
import io.mokamint.application.messages.internal.gson.CheckPrologExtraResultMessageJson;

/**
 * A provider of {@link CheckPrologExtraResultMessage}.
 */
public final class CheckPrologExtraResultMessages {

	private CheckPrologExtraResultMessages() {}

	/**
	 * Yields a {@link CheckPrologExtraResultMessage}.
	 * 
	 * @param result the result of the call
	 * @param id the identifier of the message
	 * @return the message
	 */
	public static CheckPrologExtraResultMessage of(boolean result, String id) {
		return new CheckPrologExtraResultMessageImpl(result, id);
	}

	/**
	 * Gson encoder.
	 */
	public static class Encoder extends CheckPrologExtraResultMessageEncoder {

		/**
		 * Creates a new encoder.
		 */
		public Encoder() {}
	}

	/**
	 * Gson decoder.
	 */
	public static class Decoder extends CheckPrologExtraResultMessageDecoder {

		/**
		 * Creates a new decoder.
		 */
		public Decoder() {}
	}

	/**
     * Json representation.
     */
    public static class Json extends CheckPrologExtraResultMessageJson {

    	/**
    	 * Creates the Json representation for the given message.
    	 * 
    	 * @param message the message
    	 */
    	public Json(CheckPrologExtraResultMessage message) {
    		super(message);
    	}
    }
}

==> io-mokamint-application-messages-1.3.1-sources.jar: io/mokamint/application/messages/CheckPrologExtraResultMessages.java <==
/*
Copyright 2024 Fausto Spoto

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package io.mokamint.application.messages;

import io.mokamint.application.messages.api.CheckPrologExtraResultMessage;
import io.mokamint.application.messages.internal.CheckPrologExtraResultMessageImpl;
import io.mokamint.application.messages.internal.gson.CheckPrologExtraResultMessageDecoder;
import io.mokamint.application.messages.internal.gson.CheckPrologExtraResultMessageEncoder;
import io.mokamint.application.messages.internal.gson.CheckPrologExtraResultMessageJson;

/**
 * A provider of {@link CheckPrologExtraResultMessage}.
 */
public abstract class CheckPrologExtraResultMessages {

	private CheckPrologExtraResultMessages() {}

	/**
	 * Yields a {@link CheckPrologExtraResultMessage}.
	 * 
	 * @param result the result of the call
	 * @param id the identifier of the message
	 * @return the message
	 */
	public static CheckPrologExtraResultMessage of(boolean result, String id) {
		return new CheckPrologExtraResultMessageImpl(result, id);
	}

	/**
	 * Gson encoder.
	 */
	public static class Encoder extends CheckPrologExtraResultMessageEncoder {

		/**
		 * Creates a new encoder.
		 */
		public Encoder() {}
	}

	/**
	 * Gson decoder.
	 */
	public static class Decoder extends CheckPrologExtraResultMessageDecoder {

		/**
		 * Creates a new decoder.
		 */
		public Decoder() {}
	}

	/**
     * Json representation.
     */
    public static class Json extends CheckPrologExtraResultMessageJson {

    	/**
    	 * Creates the Json representation for the given message.
    	 * 
    	 * @param message the message
    	 */
    	public Json(CheckPrologExtraResultMessage message) {
    		super(message);
    	}
    }
}
